@@ -1,7 +1,7 @@
 from appium import webdriver
 from selenium.webdriver.support.ui import WebDriverWait
 
-class driver_main() :
+class Driver_main() :
 
     desired_caps = {}
 
